GeneratedMessage class abstract
The base class for all protobuf message types.
The protoc plugin generates subclasses providing type-specific properties and methods.
Public properties and methods added here should also be added to
GeneratedMessage_reservedNames and should be unlikely to be used in a
proto file.
- Implementers
- AddWorkspaceRequest
- AddWorkspaceResponse
- AppOpsRequest
- AppOpsResponse
- CloneWorkspaceRequest
- CloneWorkspaceResponse
- Compared
- ComparedValue
- Empty
- GetWorkspaceRequest
- GetWorkspaceResponse
- LabelTransactionRequest
- LabelTransactionResponse
- ListWorkspacesResponse
- Meta
- MetaRequest
- MetaResponse
- MutatorAccountCloned
- MutatorCloneAccountRequest
- MutatorCloneAccountResponse
- MutatorModifyAccountRequest
- MutatorModifyAccountResponse
- PingRequest
- PingResponse
- RecentTransactionUpdatesRequest
- RecentTransactionUpdatesResponse
- ReleaseInfo
- ReleaseInfoResponse
- RemoveWorkspaceRequest
- RemoveWorkspaceResponse
- RpcAccount
- RpcAccountDiff
- RpcAccountModification
- RpcClonableWorkspace
- RpcClonableWorkspaceProgram
- RpcContext
- RpcCreateSnapshotResult
- RpcDeleteSnapshotResult
- RpcDiffedAccountUpdate
- RpcGetAccountInfoRequest
- RpcGetAccountInfoResponse
- RpcModifyAccountOpts
- RpcRequestAirdropRequest
- RpcRequestAirdropResponse
- RpcSnapshotableAccount
- RpcSnapshotAccount
- RpcSnapshotAccountSummary
- RpcSnapshotFilter
- RpcSnapshotMetadata
- RpcSnapshotRestoreResult
- RpcStoreAccountData
- RpcTransactionAccount
- RpcTransactionUpdate
- RpcWorkspace
- RpcWorkspaceProgram
- SnapshotCreateSnapshotRequest
- SnapshotCreateSnapshotResponse
- SnapshotDeleteSnapshotRequest
- SnapshotDeleteSnapshotResponse
- SnapshotDeleteSnapshotsMatchingRequest
- SnapshotDeleteSnapshotsMatchingResponse
- SnapshotDeleteSnapshotsMatchingResult
- SnapshotGetAccountRequest
- SnapshotGetAccountResponse
- SnapshotGetSnaphotableAccountsRequest
- SnapshotGetSnaphotableAccountsResponse
- SnapshotListSnapshotsRequest
- SnapshotListSnapshotsResponse
- SnapshotRestoreAccountsFromLastUpdatedSnapshotRequest
- SnapshotRestoreAccountsFromLastUpdatedSnapshotResponse
- SnapshotRestoreAccountsFromSnapshotRequest
- SnapshotRestoreAccountsFromSnapshotResponse
- SnapshotRetrieveAccountsInSnapshotRequest
- SnapshotRetrieveAccountsInSnapshotResponse
- SnapshotsModified
- StoreGetAccountDataRequest
- StoreGetAccountDataResponse
- StoreGetDiffedAccountUpdateRequest
- StoreGetDiffedAccountUpdateResponse
- TransactionModificationLabeled
- UnwatchWorkspaceRequest
- UnwatchWorkspaceResponse
- ValidatorInfo
- ValidatorInfoSubRequest
- ValidatorOpsRequest
- ValidatorOpsResponse
- ValidatorStats
- ValidatorStatus
- ValidatorStatusSubRequest
- VecString
- WatchWorkspaceRequest
- WatchWorkspaceResponse
- WorkspaceWatchChanged
Constructors
Properties
- eventPlugin → EventPlugin?
-
Subclasses can override this getter to be notified of changes
to protobuf fields.
no setter
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setteroverride
- info_ → BuilderInfo
-
no setter
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unknownFields → UnknownFieldSet
-
no setter
Methods
-
addExtension(
Extension extension, Object? value) → void - Adds an extension field value to a repeated field.
-
check(
) → void -
clear(
) → void - Clears all data that was set in this message.
-
clearExtension(
Extension extension) → void - Clears an extension field and also removes the extension.
-
clearField(
int tagNumber) → void - Clears the contents of a given field.
-
clone(
) → GeneratedMessage - Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
-
copyWith(
void updates(GeneratedMessage)) → GeneratedMessage -
Apply
updatesto a copy of this message. -
createEmptyInstance(
) → GeneratedMessage - Creates an empty instance of the same message type as this.
-
createMapField<
K, V> (int tagNumber, MapFieldInfo< K, V> fi) → Map<K, V> - Creates a Map representing a map field.
-
createRepeatedField<
T> (int tagNumber, FieldInfo< T> fi) → List<T> - Creates List implementing a mutable repeated field.
-
extensionsAreInitialized(
) → bool -
freeze(
) → GeneratedMessage - Make this message read-only.
-
getDefaultForField(
int tagNumber) → dynamic - Returns the default value for the given field.
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension. -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set. -
getFieldOrNull(
int tagNumber) → dynamic - Returns the value of a field, ignoring any defaults.
-
getTagNumber(
String fieldName) → int? -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present. -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber. -
hasRequiredFields(
) → bool - Whether the message has required fields.
-
isInitialized(
) → bool - Whether all required fields in the message and embedded messages are set.
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void - Merges serialized protocol buffer data into this message.
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described by GeneratedMessage.writeToJson. -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void - Merges field values from a JSON object represented as a Dart map.
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message. -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding. -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value. -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber. -
toBuilder(
) → GeneratedMessage - Creates a writable, shallow copy of this message.
-
toDebugString(
) → String - Returns a String representation of this message.
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this. -
toString(
) → String -
Returns a String representation of this message.
override
-
writeToBuffer(
) → Uint8List -
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
writeToJson(
) → String - Returns a JSON string that encodes this message.
-
writeToJsonMap(
) → Map< String, dynamic> - Returns the JSON encoding of this message as a Dart Map.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override