WorkspaceServiceClient class

Annotations
  • @GrpcServiceName.new('workspace.WorkspaceService')

Constructors

WorkspaceServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
addWorkspace(AddWorkspaceRequest request, {CallOptions? options}) → ResponseFuture<AddWorkspaceResponse>
cloneWorkspace(CloneWorkspaceRequest request, {CallOptions? options}) → ResponseFuture<CloneWorkspaceResponse>
getWorkspace(GetWorkspaceRequest request, {CallOptions? options}) → ResponseFuture<GetWorkspaceResponse>
listWorkspaces(Empty request, {CallOptions? options}) → ResponseFuture<ListWorkspacesResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeWorkspace(RemoveWorkspaceRequest request, {CallOptions? options}) → ResponseFuture<RemoveWorkspaceResponse>
toString() String
A string representation of this object.
inherited
unwatchWorkspace(UnwatchWorkspaceRequest request, {CallOptions? options}) → ResponseFuture<UnwatchWorkspaceResponse>
watchWorkspace(WatchWorkspaceRequest request, {CallOptions? options}) → ResponseFuture<WatchWorkspaceResponse>

Operators

operator ==(Object other) bool
The equality operator.
inherited